/* ~Օʉ
 * Copyright (C) 2004 Kagetani Hideto
 */
// EnbanFukusyaDlg.h : wb_[ t@C
//

#if !defined(AFX_ENBANFUKUSYADLG_H__EABF7B40_B6F1_411E_8389_F71E834072EF__INCLUDED_)
#define AFX_ENBANFUKUSYADLG_H__EABF7B40_B6F1_411E_8389_F71E834072EF__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <afxpriv.h>	// for WM_KICKIDLE
#include <ThemeButton.h>
#include <ThemeComboBox.h>
#include <ThemeProgressBar.h>
#include <ThemeLabel.h>
#include <ThemeDialog.h>
#include <scan.h>
#include <option.h>

/////////////////////////////////////////////////////////////////////////////
// CEnbanFukusyaDlg _CAO

class CEnbanFukusyaDlg : public CThemeDialog
{
// \z
public:
	CEnbanFukusyaDlg(CWnd* pParent = NULL);	// W̃RXgN^

// _CAO f[^
	//{{AFX_DATA(CEnbanFukusyaDlg)
	enum { IDD = IDD_ENBANFUKUSYA_DIALOG };
	CThemeLabel	m_StcInfo;
	CThemeLabel	m_StcWriter;
	CThemeLabel	m_StcReader;
	CThemeLabel	m_StcProgress2;
	CThemeLabel	m_StcProgress1;
	CThemeComboBox	m_CmbWriter;
	CThemeComboBox	m_CmbReader;
	CThemeProgressBar	m_Progress2;
	CThemeProgressBar	m_Progress1;
	CThemeButton	m_BtnExit;
	CThemeButton	m_BtnOK;
	//}}AFX_DATA

	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CEnbanFukusyaDlg)
	public:
	virtual BOOL DestroyWindow();
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV ̃T|[g
	//}}AFX_VIRTUAL

public:
	void SetArgReader(LPCTSTR lpszReader);
	LPCTSTR GetArgReader();
	void SetArgWriter(LPCTSTR lpszWriter);
	LPCTSTR GetArgWriter();

// Cve[V
protected:
	HICON m_hIcon;

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CEnbanFukusyaDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	virtual void OnOK();
	virtual void OnCancel();
	//}}AFX_MSG
	afx_msg LRESULT OnKickIdle(WPARAM wParam, LPARAM lParam);
	afx_msg LRESULT OnUICtl(WPARAM wParam, LPARAM lParam);
	DECLARE_MESSAGE_MAP()

private:
	void CEnbanFukusyaDlg::GetIniFilename(char *path, int bufsize);
	void LoadIniFile();
	void SaveIniFile();
	void LoadTheme();
	void DrawLogo();
	void ShowMeter1(BOOL bShow);
	void ShowMeter2(BOOL bShow);
	void ShowInfo(BOOL bShow);
	void ResizeWindow(int nStep);
	int Setting(OPTIONS *option);
	CBitmap m_bmpLogo;
	CBitmap m_bmpLogoMask;
	SCAN_t *m_pReaderDrives;
	SCAN_t *m_pWriterDrives;
	BOOL m_bRunning;
	int m_nWindowSizeStep;
	int m_nThemeNumber;
	BOOL m_bScanDone;
	int m_nAllWritableDrives;
	int m_nReadDriveISO;
	int m_nWriteDriveISO;
	int m_nReadDriveEmg;
	int m_nWriteDriveEmg;
	int m_nReadDriveNet;
	int m_nWriteDriveNet;
	CString m_csArgReader;
	CString m_csArgWriter;
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_ENBANFUKUSYADLG_H__EABF7B40_B6F1_411E_8389_F71E834072EF__INCLUDED_)
